@@ -97,9 +97,9 @@ void AccountWidget::setupWidgets()
 
     connect(leaveOnServerCheck, &QCheckBox::clicked, this, &AccountWidget::slotLeaveOnServerClicked);
     connect(leaveOnServerDaysCheck, &QCheckBox::toggled, this, &AccountWidget::slotEnableLeaveOnServerDays);
-    connect(leaveOnServerDaysSpin, qOverload<int>(&QSpinBox::valueChanged), this, &AccountWidget::slotLeaveOnServerDaysChanged);
+    connect(leaveOnServerDaysSpin, &QSpinBox::valueChanged, this, &AccountWidget::slotLeaveOnServerDaysChanged);
     connect(leaveOnServerCountCheck, &QCheckBox::toggled, this, &AccountWidget::slotEnableLeaveOnServerCount);
-    connect(leaveOnServerCountSpin, qOverload<int>(&QSpinBox::valueChanged), this, &AccountWidget::slotLeaveOnServerCountChanged);
+    connect(leaveOnServerCountSpin, &QSpinBox::valueChanged, this, &AccountWidget::slotLeaveOnServerCountChanged);
     connect(leaveOnServerSizeCheck, &QCheckBox::toggled, this, &AccountWidget::slotEnableLeaveOnServerSize);
 
     connect(checkCapabilities, &QPushButton::clicked, this, &AccountWidget::slotCheckPopCapabilities);
@@ -108,7 +108,7 @@ void AccountWidget::setupWidgets()
     encryptionButtonGroup->addButton(encryptionSSL, Transport::EnumEncryption::SSL);
     encryptionButtonGroup->addButton(encryptionTLS, Transport::EnumEncryption::TLS);
 
-    connect(encryptionButtonGroup, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked), this, &AccountWidget::slotPopEncryptionChanged);
+    connect(encryptionButtonGroup, &QButtonGroup::buttonClicked, this, &AccountWidget::slotPopEncryptionChanged);
     connect(intervalCheck, &QCheckBox::toggled, this, &AccountWidget::slotEnablePopInterval);
 
     populateDefaultAuthenticationOptions();
@@ -299,7 +299,7 @@ void AccountWidget::slotCheckPopCapabilities()
     mServerTest->setProgressBar(checkCapabilitiesProgress);
     Q_EMIT okEnabled(false);
     checkCapabilitiesStack->setCurrentIndex(1);
-    Transport::EnumEncryption::type encryptionType;
+    Transport::EnumEncryption encryptionType;
     if (encryptionSSL->isChecked()) {
         encryptionType = Transport::EnumEncryption::SSL;
     } else {
